@@ -179,8 +179,12 @@ sub insert {
     } sort(keys(%values)));
     my($fields) = join(', ', @fields);
 
-    my($base) = $self->connect();
     my($sql) = "insert into $table ( $fields ) values ( $values )";
+    if($::opt_fake) {
+	dbg($sql, "normal");
+	return 1;
+    }
+    my($base) = $self->connect();
     dbg("$sql", "mysql");
     my($stmt) = $base->prepare("$sql") or error("cannot prepare $sql : " . $base->errstr());
     $stmt->execute() or error("cannot execute $sql: " . $base->errstr());
@@ -300,6 +304,11 @@ sub update {
 	}
     } sort(keys(%values)));
 
+    if($::opt_fake) {
+	my($sql) = "update $table set $set $where";
+	dbg($sql, "normal");
+	return 1;
+    }
     #
     # Update the dictionaries before data changes so that the $where clause
     # is still valid.
@@ -387,7 +396,7 @@ sub exec {
     my($self, $sql) = @_;
     my($base) = $self->connect();
     if($::opt_fake) {
-	print "$sql;\n";
+	dbg($sql, "normal");
     } else {
 	dbg("$sql\n", "mysql");
 	my($stmt) = $base->prepare("$sql") or error("cannot prepare $sql : " . $base->errstr());
@@ -399,6 +408,7 @@ sub exec {
 	}
 	if($sql =~ /create\s+table/soi || $sql =~ /drop\s+table/soi) {
 	    delete($self->{'_table_list_'}) if(exists($self->{'_table_list_'}));
+	    delete($self->{'info_tables'}) if(exists($self->{'info_tables'}));
 	}
 	return $self->{'insertid'};
     }
@@ -458,6 +468,30 @@ sub exec_select_one {
     }
 }
 
+sub table_schema {
+    my($self, $table) = @_;
+
+    my($opts) = '';
+    $opts .= " --host=$self->{'host'} " if($self->{'host'});
+    $opts .= " --port=$self->{'port'} " if($self->{'port'});
+    $opts .= " --socket=$self->{'unix_port'} " if($self->{'unix_port'});
+    $opts .= " --user=$self->{'user'} " if($self->{'user'});
+    $opts .= " --password=$self->{'passwd'} " if($self->{'passwd'});
+
+    my($base) = $self->{'base'};
+
+    my($cmd) = "mysqldump $opts --no-data $base $table";
+    my($schema);
+    $schema = `$cmd`;
+    if($? != 0) {
+	error("$cmd: high = " . (($? >> 8) & 0xff) . " low = " . ($? & 0xff) . "\n");
+    }
+
+    $schema =~ s/^\#.*//mg;
+    $schema =~ s/\);/\)/s;
+    return $schema;
+}
+
 sub info_table {
     my($self, $table) = @_;
 
